@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate;
-$App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate::VERSION = '0.49';
+$App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate::VERSION = '0.50';
 # ABSTRACT: MsgMaker class for L<App::SpreadRevolutionaryDate> to build message with revolutionary date
 
 use Moose;
@@ -61,7 +61,6 @@ sub compute {
 
   my $feast_long = $revolutionary->feast_long;
   my $today = DateTime->today;
-  $today = DateTime->new(locale => $self->locale, day => 21, month => 6, year => $today->year);
   if ($self->special_birthday_day && $self->special_birthday_month && $self->special_birthday_name && $today->day == $self->special_birthday_day && $today->month == $self->special_birthday_month) {
       $feast_long = $revolutionary->locale->prefixes->[$self->special_birthday_prefix] . $self->special_birthday_name . $revolutionary->locale->suffix;
   }
@@ -76,7 +75,9 @@ sub compute {
       time       => $revolutionary->hms,
   );
 
-  if ($self->wikipedia_link) {
+  if ($self->special_birthday_url) {
+      $msg .= ' ' . $self->special_birthday_url;
+  } elsif ($self->wikipedia_link) {
     use URI::Escape;
     my $entry = $revolutionary->locale->wikipedia_redirect($revolutionary->month, $revolutionary->feast_short);
     $msg .= ' https://' . $self->locale . '.wikipedia.org/wiki/' . uri_escape_utf8($entry);
@@ -108,7 +109,7 @@ App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate - MsgMaker class for L
 
 =head1 VERSION
 
-version 0.49
+version 0.50
 
 =head1 METHODS
 
